@@ -51,30 +51,15 @@ class Connector(threading.Thread):
             if (doc_manager[0] is '/') or 'C:\\' in doc_manager:
                 if ('win32' or 'win64') in sys.platform:
                     shutil.copy(doc_manager, cmd_folder + "\\doc_manager.py")
-                    #CMD = ["cp " + doc_manager + " " +
-                    #  + cmd_folder + "\doc_manager.py"]
-                    #subprocess.Popen(CMD, shell=True)
                 else:
                     shutil.copy(doc_manager, cmd_folder + "/doc_manager.py")
-                    #CMD = ["cp " + doc_manager + " " +
-                    #+ cmd_folder + "/doc_manager.py"]
-                    #subprocess.Popen(CMD, shell=True)
             else:
                 if ('win32' or 'win64') in sys.platform:
                     shutil.copy(cmd_folder + "\\doc_managers\\" + doc_manager,
                                 cmd_folder + "\\doc_manager.py")
-                    #CMD = ["cp " + cmd_folder +
-                    #  "\\doc_managers\\" + doc_manager + " " +
-                    #  cmd_folder + "\\doc_manager.py"]
-                    #subprocess.Popen(CMD, shell=True)
                 else:
                     shutil.copy(cmd_folder + "/doc_managers/" + doc_manager,
                                 cmd_folder + "/doc_manager.py")
-                    #CMD = ["cp " + cmd_folder +
-                    #   "/doc_managers/" + doc_manager + " " +
-                    #   cmd_folder + "/doc_manager.py"]
-                    #subprocess.Popen(CMD, shell=True)
-
         time.sleep(1)
         from doc_manager import DocManager
         super(Connector, self).__init__()
@@ -110,15 +95,22 @@ class Connector(threading.Thread):
         #Dict of OplogThread/timestmap pairs to record progress
         self.oplog_progress = LockingDict()
 
-        if backend_url is None:
-            self.doc_manager = DocManager()
-        else:
-            self.doc_manager = DocManager(self.backend_url)
-
-        if self.doc_manager is None:
-            logging.critical('Bad backend URL!')
+        try:
+            if backend_url is None:
+                self.doc_manager = DocManager()
+            else:
+                self.doc_manager = DocManager(self.backend_url)
+        except SystemError:
+            logging.critical("MongoConnector: Bad target system URL!")
+            self.can_run = False
             return
 
+        if self.oplog_checkpoint is not None:
+            if not os.path.exists(self.oplog_checkpoint):
+                logging.critical("MongoConnector: Can't find OplogProgress file!")
+                self.doc_manager.stop()
+                self.can_run = False
+
     def join(self):
         """ Joins thread, stops it from running
         """
@@ -166,7 +158,6 @@ class Connector(threading.Thread):
                 logging.info("MongoConnector: Empty oplog progress file.")
                 return None
         except OSError:
-            pass
             return None
 
         source = open(self.oplog_checkpoint, 'r')
@@ -195,6 +186,7 @@ class Connector(threading.Thread):
         shard_coll = main_conn['config']['shards']
 
         self.read_oplog_progress()
+
         if shard_coll.find().count() == 0:
             #non sharded configuration
             try:
@@ -429,7 +421,7 @@ if __name__ == '__main__':
 
     while True:
         try:
-            time.sleep(5)
+            time.sleep(3)
             if not ct.is_alive():
                 break
         except KeyboardInterrupt:
